#----------------------------------------------------------------------
#  userpanelPassword
#----------------------------------------------------------------------

package esmith::FormMagick::Panel::userpanelPassword;

use strict;
use warnings;
use esmith::util;
use esmith::AccountsDB;
use esmith::ConfigDB;
use esmith::FormMagick;

our $accountdb = esmith::AccountsDB->open();
our $configdb = esmith::ConfigDB->open();

our @ISA = qw(esmith::FormMagick Exporter);
our $VERSION = sprintf '%d.%03d', q$Revision: 1.0 $ =~ /: (\d+).(\d+)/;
our @EXPORT = qw();

sub check_password {
    my $fm = shift;
    my $pass1 = shift;

    my $check_type;
    my $rec = $configdb->get('passwordstrength');
    $check_type = ($rec ? ($rec->prop('Users') || 'none') : 'none');

    return $fm->validate_password($check_type,$pass1);
}

sub password_compare {
	my $fm = shift;
	my $pass2 = shift;

	my $pass1 = $fm->{cgi}->param('pass');
    unless ($pass1 eq $pass2) 
    {
        $fm->error('PASSWORD_NO_MATCH');
        return undef;
    }
    return "OK";
}

sub change_password {

    my ($fm) = @_;
    my $q = $fm->{cgi};
    
    #get user and untaint
    my $UserName = $ENV{'REMOTE_USER'} ||'';
    unless (($UserName) = ($UserName =~ /^([a-z][\-\_\.a-z0-9]*)$/ ))
    {
        $fm->error('YOUR_ACCOUNT_INVALID_CHARS');
        return undef;
    }

    my $oldPass   = $q->param('oldPass');
    my $pass      = $q->param('pass');

    unless (($oldPass) = ($oldPass =~ /^(\S+)$/ ))
    {
        $fm->error('PASSWORD_OLD_INVALID_CHARS');
        return undef;
    }
    
    unless (($pass) = ($pass =~ /^([ -~]+)$/ ))
    {
        $fm->error('PASSWORD_INVALID_CHARS');
        return undef;
    }

    my $acct;
    unless ($acct = $accountdb->get($UserName))
    {
        $fm->error('YOUR_ACCOUNT_INVALID');
        return undef;
    }

    unless ($acct->prop('type') eq 'user')
    {
        $fm->error('YOUR_ACCOUNT_INVALID');
        return undef;
    }

    unless (esmith::util::setUserPasswordRequirePrevious(
		$UserName,
		$oldPass,
		$pass))
    {
        $fm->error('ERROR_PASSWORD_CHANGE');
        return undef;
    }
    
    $accountdb->set_prop($UserName, "PasswordSet", "yes");
    undef $accountdb;

    unless ( system("/sbin/e-smith/signal-event", "password-modify", $UserName ) == 0 )
    {
        $fm->error('ERROR_UPDATING');
        return undef;
    }
    
    $fm->success('PASSWORD_CHANGE_SUCCESS', 'Done');
}


1;